┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/tests
diff options
context:
space:
mode:
Diffstat (limited to 'src/tests')
-rw-r--r--src/tests/placesitemmodeltest.cpp4
1 files changed, 3 insertions, 1 deletions
diff --git a/src/tests/placesitemmodeltest.cpp b/src/tests/placesitemmodeltest.cpp
index fac0931a6..4ed4945b2 100644
--- a/src/tests/placesitemmodeltest.cpp
+++ b/src/tests/placesitemmodeltest.cpp
@@ -476,10 +476,12 @@ void PlacesItemModelTest::testDefaultViewProperties()
QFETCH(bool, expectedPreviewShow);
QFETCH(QList<QByteArray>, expectedVisibleRole);
// In order to test the default view properties, turn off the global view properties.
GeneralSettings* settings = GeneralSettings::self();
settings->setGlobalViewProps(false);
settings->save();
+ cleanup();
+ init();
ViewProperties properties(KFilePlacesModel::convertedUrl(url));
QCOMPARE(properties.viewMode(), expectedViewMode);
@@ -476,10 +476,12 @@ void PlacesItemModelTest::testDefaultViewProperties()
QFETCH(bool, expectedPreviewShow);
QFETCH(QList<QByteArray>, expectedVisibleRole);
- // In order to test the default view properties, turn off the global view properties.
+ // In order to test the default view properties, turn off the global view properties and re-init the test to reload the model.
GeneralSettings* settings = GeneralSettings::self();
settings->setGlobalViewProps(false);